@@ -3,7 +3,7 @@
 #Requires - pip install pyyaml
 
 #upload - https://www.youtube.com/watch?v=zhpI6Yhz9_4&ab_channel=MakerBytes
-#python3 setup.py sdist
+#python setup.py sdist
 #twine upload --repository-url https://upload.pypi.org/legacy/ dist/*
 
 
@@ -85,6 +85,7 @@ testsuite =""
 report = ""
 trainer = "false"
 azure_variable = "testtorun"
+pipeoutput = "false"
 
 
 def find(name):
@@ -316,13 +317,27 @@ def urlencode(name):
 def echo(stringtoprint):
     print (stringtoprint)
 
-def runcommand(command):
-    echo("platform = " + sys.platform)
-    result = subprocess.run(command,  shell=True, capture_output=True)
-    #subprocess.run(['ls', '-l'])stdout=subprocess.PIPE,
-    print((result.stdout.decode('utf-8')))
-    print((result.stderr.decode('utf-8')))
-    return result.stdout.decode('utf-8')
+def runcommand(command, stream="false"):
+    print("platform = " + sys.platform)
+    if stream == "true":
+        process = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True, encoding='utf-8')
+        output = ""
+        while(True):
+            # returns None while subprocess is running
+            retcode = process.poll() 
+            line = process.stdout.readline()
+            output = output + line
+            print(line, end = '')
+            #yield line
+            if retcode is not None:
+                break
+        return output
+    if stream == "false":    
+        result = subprocess.run(command,  shell=True, capture_output=True)
+        #subprocess.run(['ls', '-l'])stdout=subprocess.PIPE,
+        print((result.stdout.decode('utf-8')))
+        print((result.stderr.decode('utf-8')))
+        return result.stdout.decode('utf-8')
 
 def delete_reports():
     if reporttype == "directory":
@@ -376,7 +391,7 @@ def execute_tests(testlist, testset):
             command = startrunspecific + startrunpostfix + endrunprefix + endrunspecific + endrunpostfix
 
     echo("run command = " + command)
-    runcommand(command)
+    runcommand(command, pipeoutput)
     echo(os.getcwd())
     push_results()
 
@@ -595,9 +610,10 @@ def getresults():
         exit(1)    
 
 def push_results():
+    print("pushing results " + reporttype + " " + report)
     if trainer == "true":
         runcommand("trainer")
-    echo("pushing test results")
+    
     if reporttype == "directory":
         filetype = ".xml"
         if importtype == "trx":
@@ -665,7 +681,7 @@ def runtestswithappsurify(*args):
     global fullnameseparator, fullname, failfast, maxrerun, rerun, importtype, reporttype, teststorun, deletereports, startrunall, endrunall, startrunspecifi, endrunspecific
     global commit, scriptlocation, branch, runfrequency, fromcommit, repository, scriptlocation, generatefile, template, addtestsuitename, addclassname, runtemplate, testsuitesnameseparator
     global testtemplate, classnameseparator, testseparatorend, testtemplatearg1, testtemplatearg2, testtemplatearg3, testtemplatearg4, startrunpostfix, endrunprefix
-    global endrunpostfix, executetests, encodetests, testsuiteencoded, projectencoded, testsrun, trainer, azure_variable
+    global endrunpostfix, executetests, encodetests, testsuiteencoded, projectencoded, testsrun, trainer, azure_variable, pipeoutput
 
     tests=""
     testsrun=""
@@ -725,6 +741,7 @@ def runtestswithappsurify(*args):
     encodetests = "false"
     trainer = "false"
     azure_variable = "testtorun"
+    pipeoutput = "false"
     #--testsuitesnameseparator and classnameseparator need to be encoded i.e. # is %23
 
 
@@ -1230,9 +1247,11 @@ def runtestswithappsurify(*args):
             if argv[k] == "--trainer":
                 trainer = "true"
             if argv[k] == "--azurevariable":
-                azure_variable = argv[k+1]    
+                azure_variable = argv[k+1]
+            if argv[k] == "--pipeoutput":
+                pipeoutput = "true"
             if argv[k] == "--help":
-                echo("please see url for more details on this script and how to execute your tests with appsurify - https://github.com/Appsurify/AppsurifyCIScript")
+                echo("please see url for more details on this script and how to execute your tests with appsurify - https://github.com/Appsurify/AppsurifyCI")
 
     if "http://" in proxy:
         proxy = proxy.replace("http://","")
@@ -1295,6 +1314,12 @@ def runtestswithappsurify(*args):
     if runfrequency == "betweenexclusive" and fromcommit == "":
         echo("no from commit specified and runfrequency set to betweenexclusive")
         exit(1)
+    if runfrequency != "single" and branch == "":
+        echo("no branch specified")
+        exit(1)
+    if commit == "":
+        echo("no commit specified")
+        exit(1)
 
     if startrunspecific == "" and teststorun != "all":
         if teststorun != "none":
@@ -1323,6 +1348,7 @@ def runtestswithappsurify(*args):
     valuetests=""
     finalTestNames=""
     testsrun = ""
+    print("test to run = " + teststorun)
     if teststorun == "all":
         execute_tests("", 0)
         testsrun="all"
